% pop_eeglab2loreta() - export EEGLAB data to LORETA
%
% Usage:
%   >> OUTEEG = pop_eeglab2loreta( filename, srate );
%
% Inputs:
%   filename       - file name
%   srate          - sampling rate
%
% Outputs:
%   OUTEEG         - EEGLAB data structure
%
% Author: Arnaud Delorme, CNL / Salk Institute, 2005
%
% See also: eeglab2loreta()

%123456789012345678901234567890123456789012345678901234567890123456789012

% Copyright (C) 2005 Arnaud Delorme, Salk Institute, arno@salk.edu
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: pop_eeglab2loreta.m,v $

function command = pop_eeglab2loreta(EEG, varargin); 

    command = '';
    if nargin < 1
        help pop_eeglab2loreta;
        return;
    end;    
    
    if nargin > 2
        eeglab2loreta(EEG.chanlocs, EEG.icawinv, varargin{:});
        return;
    end;
    
    commandload = [ 'filepath = uigetdir(pwd, ''Select a folder'');' ...
                    'if filepath ~=0,' ...
                    '   set(findobj(''parent'', gcbf, ''tag'', ''folder''), ''string'', filepath);' ...
                    'end;' ...
                    'clear filepath;' ];
    cb_plotcomps = [ 'compinds = str2num(get(findobj(gcbf, ''tag'', ''compind''), ''string'');' ...
                     'pop_topoplot(EEG, 0, compinds);' ];
    
    listui = { { 'style' 'text'       'string' 'Ouput folder' } ...
               { 'style' 'edit'       'string' '' 'tag' 'folder' } ...
               { 'style' 'pushbutton' 'string' 'Browse' 'callback' commandload } ...
               { 'style' 'text'       'string' 'Export channel labels only' } ...
               { 'style' 'checkbox'   'string' '' } ...
               { 'style' 'text'       'string' '(check=yes)' } ...
               { 'style' 'text'       'string' 'Omit channel indices' } ...
               { 'style' 'edit'       'string' '' } ...
               { 'style' 'pushbutton' 'string' 'Select' } ...
               { 'style' 'text'       'string' 'Export component indices' } ...
               { 'style' 'edit'       'string' [ '1:' num2str(size(EEG.icawinv,2) ] } ...
               { 'style' 'pushbutton' 'Plot topo.' 'callback' cb_plotcomps } };
    geom = { [1 1 0.5] [0.8 0.2 1] [1 1 0.5] [1 1 0.5] };
    results = inputgui(geom, listui, 'pophelp(''pop_eeglab2loreta'')', 'Export EEG info to LORETA');
    
    % decode inputs
    % -------------
    folderout = results{1};
    options = {}:
    if results{2}
        options = { 'labelonly' 'on' };
    end;
    if ~isempty(results{3})
        options = { options 'excludechan' eval( [ '[' results{3} ']' ] ) };
    end;
    compnums = eval( [ '[' results{4} ']' ] )
    eeglab2loreta(EEG.chanlocs, EEG.icawinv, 'compnums', compnums, options{:});
end;

% output folder
    % labels only export
    % only export subset of channels
    % component numbers

