function [frqjck] = frqdescriptives(cfg, freq)

% frqdescriptives performs simple statistics on the output of frqanalysis
%
% [freq] = frqanastatistic(cfg, freq)
%
% cfg must be supplied, but should be emplty (cfg = []).
% freq should be organised in a structure as obtained from 
% the freqanalysis function. 
% 
% The output will depend on the input:
% 
% If the input contains only power-spectra, then only the statistics of the power is reported
% If the input contains power- and cross-spectral densities, then power and coherence are reported.
%
% If results from trials and/or tapers have not been kept, only coherence will be calculated. 
% If results from trials and/or tapers have been kept, the jackknife estimate of the SEM of 
% power and evtl. coherence are calculated. In that case, also the degrees of freedom (dof) are
% reported.

% Copyright (C) 2004, F.C. Donders Centre
%
% $Log: freqdescriptives.m,v $
% Revision 1.7  2005/01/27 08:47:21  roboos
% fixed bug in finding channel indices  (added 'exact' to strmatch)
% added version details to the configuration
%
% Revision 1.6  2005/01/20 11:03:34  jansch
% changed sgncmb into labelcmb, allowing for backwardcompatibility
%
% Revision 1.5  2004/10/08 10:17:16  jansch
% *** empty log message ***
%
% Revision 1.4  2004/10/08 06:50:18  jansch
% fixed small bug which caused a crash when cfg.keeptrials has been 'no'
%

if ~isfield(freq, 'labelcmb') & isfield(freq, 'sgncmb'),
  freq.labelcmb = freq.sgncmb;
end

csdflg = isfield(freq, 'labelcmb');

rptflg = strcmp(freq.dimord(1:3),'rpt');

if csdflg
  for labelcmblop = 1:size(freq.labelcmb,1) 
    labelcmbind(labelcmblop,1) = strmatch(freq.labelcmb(labelcmblop,1), freq.label, 'exact'); 
    labelcmbind(labelcmblop,2) = strmatch(freq.labelcmb(labelcmblop,2), freq.label, 'exact'); 
  end
end

if ~rptflg
  newdimord = freq.dimord;
  if ~csdflg
    disp('Input was averaged PSD only, allowing no statistic.')
  elseif csdflg
    if strcmp(freq.dimord(end-2:end),'frq')
      frqjck.coh = abs(freq.crsspctrm ./ ...
        sqrt(freq.powspctrm(labelcmbind(:,1),:) .* ...
        freq.powspctrm(labelcmbind(:,2),:)));
    elseif strcmp(freq.dimord(end-2:end),'tim')
      frqjck.coh = abs(freq.crsspctrm ./ ...
        sqrt(freq.powspctrm(labelcmbind(:,1),:,:) .* ...
        freq.powspctrm(labelcmbind(:,2),:,:)));
    end
  end
  frqjck.pow = freq.powspctrm;
elseif rptflg
  newdimord = freq.dimord(5:end);
  if strcmp(freq.dimord(end-2:end),'frq')
    siz = size(freq.powspctrm);
    numrpt      = siz(1);
    frqjck.dof  = numrpt;
    numlabel      = siz(2);
    numboi      = siz(3);
    jckavgpowarr = zeros(numrpt,numlabel,numboi);
    sumpowspctrm = sum(freq.powspctrm,1);
    for rptlop = 1:numrpt
      jckavgpowarr(rptlop,:,:) = (sumpowspctrm - freq.powspctrm(rptlop,:,:)) ./ (numrpt -1);
    end
    avgjckavgpow = mean(jckavgpowarr,1);
    jckavgpowdum = zeros(1,numlabel,numboi);
    for rptlop = 1:numrpt
      jckavgpowdum = jckavgpowdum + ((jckavgpowarr(rptlop,:,:) - avgjckavgpow) .^ 2);
    end
    jckavgpowsem = sqrt((numrpt-1) .* jckavgpowdum ./ numrpt);
    avgpow = sumpowspctrm ./ numrpt;
    frqjck.pow = reshape(avgpow,[numlabel,numboi]);
    frqjck.jckpowsem = reshape(jckavgpowsem,[numlabel,numboi]);
    if csdflg
      numlabelcmb   = size(freq.labelcmb,1);
      jckcoharr = zeros(numrpt,numlabelcmb,numboi);
      sumcrsspctrm = sum(freq.crsspctrm,1);
      for rptlop = 1:numrpt
        jckcoharr(rptlop,:,:) = abs((sumcrsspctrm - freq.crsspctrm(rptlop,:,:)) ./ ...
          sqrt((sumpowspctrm(1,labelcmbind(:,1),:) - freq.powspctrm(rptlop,labelcmbind(:,1),:)) .* ...
          (sumpowspctrm(1,labelcmbind(:,2),:) - freq.powspctrm(rptlop,labelcmbind(:,2),:))));
      end
      avgjckcoh = mean(jckcoharr,1);
      jckcohdum = zeros(1,numlabelcmb,numboi);
      for rptlop = 1:numrpt
        jckcohdum = jckcohdum + ((jckcoharr(rptlop,:,:) - avgjckcoh) .^ 2);
      end
      jckcohsem = sqrt((numrpt-1) .* jckcohdum ./ numrpt);
      coh = abs(sumcrsspctrm ./ ...
        sqrt(sumpowspctrm(:,labelcmbind(:,1),:) .* ...
        sumpowspctrm(:,labelcmbind(:,2),:)));
      frqjck.coh = reshape(coh,[numlabelcmb,numboi]);
      frqjck.jckcohsem = reshape(jckcohsem,[numlabelcmb,numboi]);
    end
  elseif strcmp(freq.dimord(end-2:end),'tim')
    siz = size(freq.powspctrm);
    numrpt      = siz(1);
    numlabel      = siz(2);
    numfoi      = siz(3);
    numtoi      = siz(4);
    frqjck.dof  = zeros(numfoi,numtoi);
    jckavgpowarr = zeros(numrpt,numlabel,numfoi,numtoi);
    for toilop = 1:numtoi
      for foilop = 1:numfoi
        finiteind = find(isfinite(freq.powspctrm(:,1,foilop,toilop)));
        numfiniteind = length(finiteind);
        frqjck.dof(foilop,toilop) = numfiniteind;
        if numfiniteind < 3
          jckavgpowarr(:,:,foilop,toilop) = nan;
        else 
          sumpowspctrm = sum(freq.powspctrm(finiteind,:,foilop,toilop),1);
          for rptlop = 1:length(finiteind)
            jckavgpowarr(rptlop,:,foilop,toilop) = (sumpowspctrm - ...
              freq.powspctrm(finiteind(rptlop),:,foilop,toilop)) ./ (numfiniteind -1);
          end
          jckavgpowarr(numfiniteind+1:end,:,foilop,toilop) = nan;
        end
      end
    end
    jckavgpowdum = zeros(1,numlabel,numfoi,numtoi);
    for toilop = 1:numtoi
      for foilop = 1:numfoi
        finiteind = find(isfinite(jckavgpowarr(:,1,foilop,toilop)));
        numfiniteind = length(finiteind);
        if numfiniteind < 3
          jckavgpowdum(1,:,foilop,toilop) = nan;
        else
          avgjckavgpow = mean(jckavgpowarr(finiteind,:,foilop,toilop),1);
          for rptlop = 1:numfiniteind
            jckavgpowdum(1,:,foilop,toilop) = jckavgpowdum(1,:,foilop,toilop) + ...
              ((jckavgpowarr(finiteind(rptlop),:,foilop,toilop) - avgjckavgpow) .^ 2);
          end
        end
      end
    end
    jckavgpowsem = sqrt((numrpt-1) .* jckavgpowdum ./ numrpt);
    avgpow = zeros(1,numlabel,numfoi,numtoi);
    for toilop = 1:numtoi
      for foilop = 1:numfoi
        finiteind = find(isfinite(freq.powspctrm(:,1,foilop,toilop)));
        numfiniteind = length(finiteind);
        if numfiniteind < 3
          avgpow(:,:,foilop,toilop) = nan;
        else 
          avgpow(1,:,foilop,toilop) = mean(freq.powspctrm(finiteind,:,foilop,toilop),1);
        end
      end
    end
    frqjck.pow = reshape(avgpow,[numlabel,numfoi,numtoi]);
    frqjck.jckpowsem = reshape(jckavgpowsem,[numlabel,numfoi,numtoi]);
    if csdflg
      numlabelcmb   = size(freq.labelcmb,1);
      jckcoharr = zeros(numrpt,numlabelcmb,numfoi,numtoi);
      for toilop = 1:numtoi
        for foilop = 1:numfoi
          finiteind = find(isfinite(freq.crsspctrm(:,1,foilop,toilop)));
          if length(finiteind) < 3
            jckcoharr(:,:,foilop,toilop) = nan;
          else 
            sumcrsspctrm = sum(freq.crsspctrm(finiteind,:,foilop,toilop),1);
            sumpowspctrm = sum(freq.powspctrm(finiteind,:,foilop,toilop),1);
            for rptlop = 1:length(finiteind)
              jckcoharr(rptlop,:,foilop,toilop) = abs(...
                (sumcrsspctrm - freq.crsspctrm(finiteind(rptlop),:,foilop,toilop)) ./ ...
                sqrt((sumpowspctrm(1,labelcmbind(:,1)) - ...
                freq.powspctrm(finiteind(rptlop),labelcmbind(:,1),foilop,toilop)) .* ...
                (sumpowspctrm(1,labelcmbind(:,2)) - ...
                freq.powspctrm(finiteind(rptlop),labelcmbind(:,2),foilop,toilop))));
            end
            jckcoharr(length(finiteind)+1:end,:,foilop,toilop) = nan;
          end
        end
      end
      jckcohdum = zeros(1,numlabelcmb,numfoi,numtoi);
      for toilop = 1:numtoi
        for foilop = 1:numfoi
          finiteind = find(isfinite(jckcoharr(:,1,foilop,toilop)));
          if length(finiteind) < 3
            jckcohdum(1,:,foilop,toilop) = nan;
          else
            avgjckcoh = mean(jckcoharr(finiteind,:,foilop,toilop),1);
            for rptlop = 1:length(finiteind)
              jckcohdum(1,:,foilop,toilop) = jckcohdum(1,:,foilop,toilop) + ...
                ((jckcoharr(finiteind(rptlop),:,foilop,toilop) - avgjckcoh) .^ 2);
            end
          end
        end
      end
      jckcohsem = sqrt((numrpt-1) .* jckcohdum ./ numrpt);
      coh = zeros(1,numlabelcmb,numfoi,numtoi);
      for toilop = 1:numtoi
        for foilop = 1:numfoi
          finiteind = find(isfinite(freq.crsspctrm(:,1,foilop,toilop)));
          if length(finiteind) < 3
            coh(:,:,foilop,toilop) = nan;
          else 
            sumcrsspctrm = sum(freq.crsspctrm(finiteind,:,foilop,toilop),1);
            sumpowspctrm = sum(freq.powspctrm(finiteind,:,foilop,toilop),1);
            coh(1,:,foilop,toilop) = abs(sumcrsspctrm ./ ...
              sqrt((sumpowspctrm(1,labelcmbind(:,1))) .* ...
              (sumpowspctrm(1,labelcmbind(:,2)))));
          end
        end
      end
      frqjck.coh = reshape(coh,[numlabelcmb,numfoi,numtoi]);
      frqjck.jckcohsem = reshape(jckcohsem,[numlabelcmb,numfoi,numtoi]);
    end
  end
end

frqjck.powspctrm = frqjck.pow;
frqjck = rmfield(frqjck,'pow');

if rptflg
  frqjck.powspctrmsem = frqjck.jckpowsem;
  frqjck = rmfield(frqjck,'jckpowsem');
end  
if csdflg
  frqjck.cohspctrm = frqjck.coh;
  frqjck = rmfield(frqjck,'coh');
  if isfield(freq, 'sgncmb')
    frqjck.labelcmb = freq.sgncmb;
  elseif isfield(freq, 'labelcmb')
    frqjck.labelcmb = freq.labelcmb;
  end
  if rptflg
    frqjck.cohspctrmsem = frqjck.jckcohsem;
    frqjck = rmfield(frqjck,'jckcohsem');
  end
end

if strcmp(freq.dimord(end-2:end),'tim')
  frqjck.toi    = freq.toi;
end

frqjck.label    = freq.label;
frqjck.dimord   = newdimord;
frqjck.foi      = freq.foi;
if isfield(freq, 'grad')
  frqjck.grad      = freq.grad;
end
if ~rptflg & isfield(freq,'dof'),
  frqjck.dof = freq.dof;
end

% add version information to the configuration
try
  % get the full name of the function
  cfg.version.name = mfilename('fullpath');
catch
  % required for compatibility with Matlab versions prior to release 13 (6.5)
  [st, i] = dbstack;
  cfg.version.name = st(i);
end
cfg.version.id = '$Id: freqdescriptives.m,v 1.7 2005/01/27 08:47:21 roboos Exp $';
try, cfg.previous = freq.cfg; end

% remember the configuration details
frqjck.cfg = cfg;
