function [dat] = read_nex_data(filename, hdr, begsample, endsample, chanindx)

% READ_NEX_DATA for Plexon *.nex file
%
% Use as
%   [dat] = read_nex_data(filename, hdr, begsample, endsample, chanindx)
%
% See also READ_NEX_HEADER, READ_NEX_EVENT

header = hdr.nex;
smpfrq = hdr.Fs;
sgn    = chanindx;
nsmp   = (endsample-begsample+1);
dat    = zeros(hdr.nChans, nsmp);

fid = fopen(filename, 'r', 'ieee-le');
for sgnlop=1:length(sgn)

  if header.varheader(sgn(sgnlop)).typ == 0
    % read a spike channel
    status = fseek(fid,header.varheader(sgn(sgnlop)).offset,'bof');
    
    % read the sample indices at which spikes occurred
    dum = fread(fid,header.varheader(sgn(sgnlop)).cnt,'int32');
    % downsample from 40kHz to the A/D sampling frequency
    dum = dum ./ (header.filheader.frequency./smpfrq);
    dum = round(dum);
    % select only samples between the desired begin and end
    dum = dum(find(dum>=begsample & dum<=endsample));
    % convert sample indices into a continuous signal
    if ~isempty(dum)
      dum = histc(dum-begsample+1, 1:nsmp, 1);
      dat(sgnlop,:) = dum(:)';
    end

  elseif header.varheader(sgn(sgnlop)).typ == 5
    % read an A/D channel
    status = fseek(fid,header.varheader(sgn(sgnlop)).offset,'bof');
    
    % this just reads the times of LFP starts
    tim = round((fread(fid,header.varheader(sgn(sgnlop)).cnt,'int32'))./ ((header.filheader.frequency)./smpfrq));
    % this just reads the indices of LFP starts
    ind = (fread(fid,header.varheader(sgn(sgnlop)).cnt,'int32'));
    if length(ind)>1
      error('multiple A/D segments are not supported');
    end
    
    % seek to the beginning of the interesting data, correct for the A/D card initialisation delay
    fseek(fid,(begsample+tim-1)*2, 'cof');
    % read the actual data for the whole channel
    dum = fread(fid,nsmp,'int16');
    % convert to mV
    dat(sgnlop,:) = dum(:)' * header.varheader(sgn(sgnlop)).adtomv;

  else
    % warning(sprintf('unsupported data format for channel %s', hdr.label{sgn(sgnlop)}));
  end

end
status = fclose(fid);

