function cfg = SinglePlotTFR(cfg,data)
%
% --------------------------------------------------------------------------
% SingePlotTFR plots the time-frequency representation of a single channel
% using the output of FREQANALYSIS or WAVELETANALYSIS.
%
%
% Use as
%   SinglePlotTFR(cfg,data)
%    
% data is produced by FREQANALYSIS or WAVELETANALYSIS.
% cfg structure contains all configurations details for the plotting
%
% cfg.baseline        = 'yes','no' or [time1 time2] (default = 'no')  
% cfg.baselinetype    = 'absolute' or 'relative' (default = 'absolute')   
% cfg.xlim            = 'maxmin' or [xmin xmax] (default = 'maxmin')
% cfg.ylim            = 'maxmin' or [ymin ymax] (default = 'maxmin')
% cfg.zlim            = 'maxmin','absmax' or [zmin zmax] (default = 'maxmin')
% cfg.channel         = channel number (not label; default = 1)



if ~isfield(cfg,'baseline'),        cfg.baseline   = 'no'; end;
if ~isfield(cfg,'baselinetype'),    cfg.baselinetype = 'absolute'; end;
if ~isfield(cfg,'xlim'),            cfg.xlim       = 'maxmin'; end;
if ~isfield(cfg,'ylim'),            cfg.ylim       = 'maxmin'; end;
if ~isfield(cfg,'zlim'),            cfg.zlim       = 'maxmin'; end;
if ~isfield(cfg,'channel'),         cfg.channel    = 1; end;



TFR = data.powspctrm;


if ~strcmp(cfg.baseline,'no')
    if strcmp(cfg.baseline,'yes') 
        cfg.baseline = [];
        cfg.baseline(1) = min(data.toi);
        cfg.baseline(2) = 0;          
    end
        
    tidx = find(data.toi >= cfg.baseline(1) & data.toi <= cfg.baseline(2));

    for k=1:size(TFR,2)
        for l=1:size(TFR,1)
            TFRbl(l,k) = squeeze(nan_mean(TFR(l,k,tidx),3));
        end
    end 
    

    for k=1:size(TFR,2)
        for l=1:size(TFR,1)
            if strcmp(cfg.baselinetype,'absolute')
                TFR(l,k,:) = TFR(l,k,:) - TFRbl(l,k);             
            elseif strcmp(cfg.baselinetype,'relative')
                TFR(l,k,:) = 100 * ((TFR(l,k,:) - TFRbl(l,k))./TFRbl(l,k));             
            end
        end
    end 
end

 
if strcmp(cfg.xlim,'maxmin')
    xmin = min(data.toi);
    xmax = max(data.toi);   
else
    xmin = cfg.xlim(1); 
    xmax = cfg.xlim(2); 
end


if strcmp(cfg.ylim,'maxmin')
    ymin = min(data.foi);
    ymax = max(data.foi);   
else
    ymin = cfg.ylim(1); 
    ymax = cfg.ylim(2); 
end



if strcmp(cfg.zlim,'maxmin')
    zmin = min(min(min(TFR(cfg.channel,:,:))));
    zmax = max(max(max(TFR(cfg.channel,:,:))));
elseif strcmp(cfg.zlim,'absmax')
    mval = max([abs(min(min(min(TFR(cfg.channel,:,:))))) abs(max(max(max(TFR(cfg.channel,:,:))))) ]); 
    zmin = - mval;
    zmax = mval;
else
    zmin = cfg.zlim(1); 
    zmax = cfg.zlim(2); 
end


xidc = find(data.toi >= xmin & data.toi <= xmax);
yidc = find(data.foi >= ymin & data.foi <= ymax);

data.toi = data.toi(xidc);
data.foi =  data.foi(yidc);
TFR = TFR(:,yidc,xidc);
TFR = shiftdim(TFR,1);
imagesc(data.toi, data.foi, TFR(:,:,cfg.channel), [zmin,zmax]);axis xy;colorbar;




