%
% Linear and non-linear warping toolbox
%
% This is a collection of 3 dimensional linear and non-linear warping
% routines which operate on point clouds (e.g. vertices, electrodes).
% All these functions are modelled after Roger P. Woods' AIR 3.08
% package, and I refer to its documentation for more details.
% http://bishopw.loni.ucla.edu/AIR3/
% 
% General functions
%   TRANSLATE   performes a translation
%   ROTATE      performes a rotation around the x, y and z-axis
%   WARP3D      performs a linear or nonlinear transformation
%   WARPFUN     computes the mean distance after linear or nonlinear warping
%   DIST_PNT    computes the distance between each point in two 3D clouds
%
% Functions which perform an (non) linear optimization of the warping process
%   WARP_PNT    determine intermediate 3D positions using warping
%   WARP_EL     determine intermediate electrode positions using warping
%
% Functions to create a homogenous spatial transformation matrix
% for linear warping in three dimensions
%   RIGIDBODY            6 parameters
%   GLOBALRESCALE        7 parameters
%   TRADITIONAL          9 parameters
%   AFFINE              12 parameters
%   PERSPECTIVE         15 parameters
%
% Functions to create a homogenous spatial transformation matrix
% for two dimensional warping in 3d space
%   RIGIDBODY2D          3 parameters
%   GLOBALRESCALE2D      4 parameters
%   AFFINE2D             6 parameters
%   PERSPECTIVE2D        8 parameters
%
% Nonlinear warping is implemented only in three dimensions, and can be done
% from the 1th order (affine, 12 parameters) up to 5th order (168 parameters).
%
% Copyright (C) 2000-2004 Robert Oostenveld
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: Contents.m,v $
% Revision 1.3  2005/03/21 15:45:02  roboos
% changed tabs by spaces
%
% Revision 1.2  2004/05/19 09:57:07  roberto
% added GPL copyright statement, added CVS log item
%
