function [H] = globalrescale2d(f);

% GLOBALRESCALE2D creates the homogenous spatial transformation matrix
%   for a 4 parameter rigid-body transformation with global rescaling
%   on the first two dimensions
%
% H = globalrescale2d(f)
%
% The transformation vector f should contain the 
%	x-shift
%	y-shift
% followed by the
%	yaw   (rotation around z-axis)
% followed by the
%	global rescaling factor
%
% See also WARP3D

% Copyright (C) 2000-2004, Robert Oostenveld
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: globalrescale2d.m,v $
% Revision 1.2  2004/05/19 09:57:07  roberto
% added GPL copyright statement, added CVS log item
%

% compute the homogenous transformation matrix for the translation
T = eye(4,4);
T(1,4) = f(1);
T(2,4) = f(2);

% precompute the sin/cos values of the angles
cZ = cos(f(3));
sZ = sin(f(3));

% compute the homogenous transformation matrix for the rotation
R = eye(4,4);
R(1,1) =  cZ;
R(1,2) =  sZ;
R(2,1) = -sZ;
R(2,2) =  cZ;

% compute the homogenous transformation matrix for the global scaling
G = eye(4,4);
G(1,1) = f(4);
G(2,2) = f(4);

% compute the homogenous coordinate transformation matrix for use by WARP3D
H = T*R*G;

