function [H] = perspective(f);

% PERSPECTIVE creates the homogenous spatial transformation matrix
%   for a 15 parameter "perspective" transformation
%   
% The perspective model requires only that points on a line 
% before transformation remain on a line after transformation.
%
% H = perspective(f)
%
% The transformation vector f contains the independent parameters,
% which corresponds to the homogenous transformation matrix H
%     [ f1  f2  f3  f4]
%     [ f5  f6  f7  f8]
%     [ f9 f10 f11 f12]
%     [f13 f14 f15   1]
%
% See also WARP3D

% Copyright (C) 2000-2004, Robert Oostenveld
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: perspective.m,v $
% Revision 1.2  2004/05/19 09:57:07  roberto
% added GPL copyright statement, added CVS log item
%

% set up the homogenous coordinate transformation matrix for use by WARP3D
H = [  f(1)  f(2)  f(3)  f(4)
       f(5)  f(6)  f(7)  f(8)
       f(9) f(10) f(11) f(12)
      f(13) f(14) f(15)    1  ];

