function [output] = scale(S, input);

% SCALE performs a 3D scaling on the input coordinates
% 
% Use as
%   [output] = translate(S, input)
% where
%   S		[sx, sy, sz] scaling along each of the axes
%   input	Nx3 matrix with the points before scaling
%   output	Nx3 matrix with the points after scaling
%
% Or as
%   [Hs] = translate(S)
% where
%   S		[sx, sy, sz] scaling along each of the axes
%   Hs	corresponding homogenous transformation matrix

% Copyright (C) 2000-2004, Robert Oostenveld
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: scale.m,v $
% Revision 1.1  2004/05/19 09:57:07  roberto
% added GPL copyright statement, added CVS log item
%

if nargin==1
  % compute and return the homogenous transformation matrix
  output = eye(4);
  output(1,1) = S(1);
  output(2,2) = S(2);
  output(3,3) = S(3);
else
  % apply the transformation on the input points
  output(:,1) = input(:,1) * S(1);
  output(:,2) = input(:,2) * S(2);
  output(:,3) = input(:,3) * S(3);
end
